@@ -3,11 +3,10 @@ which includes the input and output fields for the model,
 as well as the OCR data and page images of the document"""
 import copy
 import itertools
-import logging
 import multiprocessing
 import os
 from collections import OrderedDict
-from typing import Dict, List, Tuple, Any, Optional, Callable
+from typing import Dict, List, Tuple, Any, Optional, Callable, Union
 
 import fitz
 import pandas as pd
@@ -22,7 +21,7 @@ from pycognaize.document.field.field import Field
 from pycognaize.document.page import Page
 from pycognaize.document.tag import TableTag, ExtractionTag
 from pycognaize.document.tag.cell import Cell
-from pycognaize.document.tag.tag import Tag
+from pycognaize.document.tag.tag import BoxTag, LineTag
 
 
 class Document:
@@ -75,10 +74,10 @@ class Document:
 
     @staticmethod
     def get_matching_table_cells_for_tag(
-            tag: Tag,
+            tag: BoxTag,
             table_tags: List[TableTag],
             one_to_one: bool
-    ) -> List[Tuple[Tag, TableTag, Cell, float]]:
+    ) -> List[Tuple[BoxTag, TableTag, Cell, float]]:
         """Create a list which includes the original extraction tag,
            the corresponding table tag and Cell objects
            and the IOU of the intersection
@@ -116,7 +115,7 @@ class Document:
 
     def get_table_cell_overlap(
             self, source_field: str,
-            one_to_one: bool) -> List[Tuple[Tag, TableTag, Cell, float]]:
+            one_to_one: bool) -> List[Tuple[BoxTag, TableTag, Cell, float]]:
         """Create a list which includes the original extraction tag,
            the corresponding table tag and Cell objects
            and the IOU of the intersection
@@ -419,7 +418,8 @@ class Document:
 
     def _collect_all_tags_for_fields(self,
                                      field_names: List[str],
-                                     is_input_field: bool = True) -> List[Tag]:
+                                     is_input_field: bool = True)\
+            -> List[Union[BoxTag, LineTag]]:
         """Collect all tags of given field names from either input or output
             fields
 
@@ -498,7 +498,7 @@ class Document:
 
 
 def annotate_pdf(doc: fitz.Document,
-                 tag: Tag,
+                 tag: BoxTag,
                  color: str,
                  opacity: float = 0.3) -> bytes:
     """An annotated Document pdf in bytes"""
@@ -518,36 +518,3 @@ def annotate_pdf(doc: fitz.Document,
     annot.set_opacity(opacity)
     annot.update()
     return doc.write()
-
-
-def filter_out_invalid_tables(tables):
-    valid_tables = []
-    for table in tables:
-        if not table.tags:
-            logging.warning('removing table with no tags')
-            continue
-
-        valid_tables.append(table)
-    return valid_tables
-
-
-def assign_indices_to_tables(tables: List['Field']):
-    tables_dict = {}
-    valid_tables = filter_out_invalid_tables(tables)
-    tables = sorted(valid_tables, key=lambda x: (
-        x.tags[0].page.page_number, x.tags[0].top, x.tags[0].left))
-
-    for table in tables:
-        page_number = table.tags[0].page.page_number
-        try:
-            # find all tables in the current page
-            # and get the index for next table
-            table_last_index = [
-                current_index
-                for (table_page_number, current_index) in tables_dict.keys()
-                if page_number == table_page_number
-            ][-1] + 1
-        except IndexError:
-            table_last_index = 0
-        tables_dict[(page_number, table_last_index)] = table
-    return tables_dict
